This function works with code split into parts identified by brackets. The format is as follows:
{
...
code from part 1
...
} # part 1
{
...
} # part 2
It automatically identifies parts to fold/unfold easily.
Shortcuts required:
"fold all brackets": shift + alt + S (Windows) / ctrl + shift + up (Mac)
"expand fold": shift + alt + D (Windows) / ctrl + shift + down (Mac)
foldAllBr(time = FALSE, debug_getTbl = FALSE)A list containing:
debug_info: A data frame with debugging information if debug_getTbl = TRUE.
timer_plot: A ggplot object visualizing execution times if time = TRUE.
If both parameters are FALSE, the function returns a list with NULL values.
Logical. If `TRUE`, the function will return ggplot object
visualizing execution times for each step.
Logical. If `TRUE`, returns the `docContent` table with tags for debugging purposes.