sepThsd: Quick Number Formatting with Custom Defaults
Description
A wrapper for the `format` function, designed to format numbers
with custom defaults for thousands separator, number of significant digits,
and scientific notation.
# Format with a comma as a thousands separator and 3 significant digitssepThsd(1234567.89, big.mark = ",", digits = 3)
# Use scientific notationsepThsd(1234567.89, scientific = TRUE)